<?php

namespace B2buy\Insurance\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use B2buy\Insurance\Models\Insurance;

class InsurancePolicy
{

    /**
     * Determine if the given user can view the insurance.
     *
     * @param UserPolicyInterface $authUser
     * @param Insurance $insurance
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Insurance $insurance)
    {
        if ($authUser->canDo('insurance.insurance.view') && $authUser->isAdmin()) {
            return true;
        }

        return $insurance->user_id == user_id() && $insurance->user_type == user_type();
    }

    /**
     * Determine if the given user can create a insurance.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('insurance.insurance.create');
    }

    /**
     * Determine if the given user can update the given insurance.
     *
     * @param UserPolicyInterface $authUser
     * @param Insurance $insurance
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Insurance $insurance)
    {
        if ($authUser->canDo('insurance.insurance.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $insurance->user_id == user_id() && $insurance->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given insurance.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Insurance $insurance)
    {
        return $insurance->user_id == user_id() && $insurance->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given insurance.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Insurance $insurance)
    {
        if ($authUser->canDo('insurance.insurance.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given insurance.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Insurance $insurance)
    {
        if ($authUser->canDo('insurance.insurance.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
